@@ -72,7 +72,7 @@ a single `include_cpp!` section), and we always generate the same number of each
 type of file.
 ";
 
-fn main() {
+fn main() -> miette::Result<()> {
     let matches = App::new("autocxx-gen")
         .version(crate_version!())
         .author(crate_authors!())
@@ -195,8 +195,7 @@ fn main() {
     let mut parsed_file = parse_file(
         matches.value_of("INPUT").unwrap(),
         matches.is_present("auto-allowlist"),
-    )
-    .expect("Unable to parse Rust file and interpret autocxx macro");
+    )?;
     let incs = matches
         .values_of("inc")
         .unwrap_or_default()
@@ -231,9 +230,7 @@ fn main() {
     // In future, we should provide an option to write a .d file here
     // by passing a callback into the dep_recorder parameter here.
     // https://github.com/google/autocxx/issues/56
-    parsed_file
-        .resolve_all(incs, &extra_clang_args, None, &cpp_codegen_options)
-        .expect("Unable to resolve macro");
+    parsed_file.resolve_all(incs, &extra_clang_args, None, &cpp_codegen_options)?;
     let outdir: PathBuf = matches.value_of_os("outdir").unwrap().into();
     if matches.is_present("gen-cpp") {
         let cpp = matches.value_of("cpp-extension").unwrap();
@@ -279,6 +276,7 @@ fn main() {
             write_placeholders(&outdir, counter, desired_number, "include.rs");
         }
     }
+    Ok(())
 }
 
 fn get_option_string(option: &str, matches: &clap::ArgMatches) -> Option<String> {
